/* GObject - GLib Type, Object, Parameter and Signal Library
 * Copyright (C) 1998, 1999, 2000 Tim Janik and Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GLIB_GOBJECT_H__
#define __GLIB_GOBJECT_H__

/* topmost include file for GObject header files */
#include	<gobject/gboxed.h>
#include	<gobject/gbsearcharray.h>
#include	<gobject/genums.h>
#include	<gobject/gobject.h>
#include	<gobject/gparam.h>
#include	<gobject/gparamspecs.h>
#include	<gobject/gsignal.h>
#include	<gobject/gtype.h>
#include	<gobject/gtypemodule.h>
#include	<gobject/gtypeplugin.h>
#include	<gobject/gvalue.h>
#include	<gobject/gvaluearray.h>
#include	<gobject/gvaluetypes.h>


#endif /* __GLIB_GOBJECT_H__ */
